@@ -34,8 +34,8 @@
 /* Undocumented macros, especially those whose name start with YY_,
    are private implementation details.  Do not rely on them.  */
 
-#ifndef YY_ZEND_POBJ_PHP_7_4_5_PHP_7_4_5_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED
-# define YY_ZEND_POBJ_PHP_7_4_5_PHP_7_4_5_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED
+#ifndef YY_ZEND_BUILD_TMP_POBJ_PHP_7_4_7_PHP_7_4_7_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED
+# define YY_ZEND_BUILD_TMP_POBJ_PHP_7_4_7_PHP_7_4_7_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -44,10 +44,10 @@
 extern int zenddebug;
 #endif
 /* "%code requires" blocks.  */
-#line 49 "/pobj/php-7.4.5/php-7.4.5/Zend/zend_language_parser.y" /* yacc.c:1921  */
+#line 49 "/build/tmp/pobj/php-7.4.7/php-7.4.7/Zend/zend_language_parser.y" /* yacc.c:1921  */
 
 
-#line 51 "/pobj/php-7.4.5/php-7.4.5/Zend/zend_language_parser.h" /* yacc.c:1921  */
+#line 51 "/build/tmp/pobj/php-7.4.7/php-7.4.7/Zend/zend_language_parser.h" /* yacc.c:1921  */
 
 /* Token type.  */
 #include "zend.h"
@@ -204,4 +204,4 @@ extern int zenddebug;
 
 ZEND_API int zendparse (void);
 
-#endif /* !YY_ZEND_POBJ_PHP_7_4_5_PHP_7_4_5_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED  */
+#endif /* !YY_ZEND_BUILD_TMP_POBJ_PHP_7_4_7_PHP_7_4_7_ZEND_ZEND_LANGUAGE_PARSER_H_INCLUDED  */
